//------------------------------------------------------------
//    knob
//------------------------------------------------------------
#ifndef __KNOB_H__
#define __KNOB_H__
#include <wx/wx.h>
#include <wx/image.h>
#include <vector>
class MouseStatus;
extern const unsigned int default_radius;
extern const wxEventType myEVT_KNOB_UPDATED;
//------------------------------------------------------------
//    class Knob
//------------------------------------------------------------
class Knob: public wxControl {
public:
	Knob(wxWindow* parent,
		wxWindowID id,
		double val1, double min1, double max1,
		int radius1 = default_radius,
		long style = wxNO_BORDER);
	~Knob();
	bool Create(wxWindow* parent,
		wxWindowID id,
		double val1, double min1, double max1,
		int radius1 = default_radius,
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxSL_HORIZONTAL);
	wxSize DoGetBestSize() const;
	void OnPaint(wxPaintEvent& event);
	void OnMouse(wxMouseEvent& event);
	void OnMouseMove(wxMouseEvent& event);
	void OnSize(wxSizeEvent& event);
	void Render();
	void SetScaleDivision(const int div1);
	void UpdateScale();
	void SetKnobRadius(const int r1);
	void SetValue(const double v1);
	void SetRange(const double min1, const double max1)
	{
		min = min1;
		max = max1;
		if(val < min) val = min;
		else if(val > max) val = max;
	}
	double GetMin() const { return min; }
	double GetMax() const { return max; }
	double GetValue() const { return val; }
private:
	MouseStatus* mouse_1;
	int radius;
	std::vector<std::vector<int> > lines;
	int divcount;
	int xorig;
	int yorig;
	double val;
	double min;
	double max;
	double angle;
	double min_angle;
	double max_angle;
	wxColour knob_colour;
	wxColour line_colour;
};

#endif

